Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(411)

Unified Diff: ios/web_view/internal/web_view_network_delegate.h

Issue 2715043002: Replace prefix of ios/web_view C++ classes. (Closed)
Patch Set: Respond to comments. Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ios/web_view/internal/web_view_browser_state.mm ('k') | ios/web_view/internal/web_view_network_delegate.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ios/web_view/internal/web_view_network_delegate.h
diff --git a/ios/web_view/internal/criwv_network_delegate.h b/ios/web_view/internal/web_view_network_delegate.h
similarity index 84%
rename from ios/web_view/internal/criwv_network_delegate.h
rename to ios/web_view/internal/web_view_network_delegate.h
index 2bbb4a7958e8fbf4ff57464006b33d0639954b1c..bcc12531bd00c1d2fbce1d38865e399c2688c9db 100644
--- a/ios/web_view/internal/criwv_network_delegate.h
+++ b/ios/web_view/internal/web_view_network_delegate.h
@@ -2,19 +2,19 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef IOS_WEB_VIEW_INTERNAL_CRIWV_NETWORK_DELEGATE_H_
-#define IOS_WEB_VIEW_INTERNAL_CRIWV_NETWORK_DELEGATE_H_
+#ifndef IOS_WEB_VIEW_INTERNAL_WEB_VIEW_NETWORK_DELEGATE_H_
+#define IOS_WEB_VIEW_INTERNAL_WEB_VIEW_NETWORK_DELEGATE_H_
#include "base/macros.h"
#include "net/base/network_delegate_impl.h"
namespace ios_web_view {
-// CWV-specific implementation of NetworkDelegate.
-class CRIWVNetworkDelegate : public net::NetworkDelegateImpl {
+// WebView implementation of NetworkDelegate.
+class WebViewNetworkDelegate : public net::NetworkDelegateImpl {
public:
- CRIWVNetworkDelegate();
- ~CRIWVNetworkDelegate() override;
+ WebViewNetworkDelegate();
+ ~WebViewNetworkDelegate() override;
private:
// net::NetworkDelegate implementation.
@@ -53,9 +53,9 @@ class CRIWVNetworkDelegate : public net::NetworkDelegateImpl {
bool OnCanAccessFile(const net::URLRequest& request,
const base::FilePath& path) const override;
- DISALLOW_COPY_AND_ASSIGN(CRIWVNetworkDelegate);
+ DISALLOW_COPY_AND_ASSIGN(WebViewNetworkDelegate);
};
} // namespace ios_web_view
-#endif // IOS_WEB_VIEW_INTERNAL_CRIWV_NETWORK_DELEGATE_H_
+#endif // IOS_WEB_VIEW_INTERNAL_WEB_VIEW_NETWORK_DELEGATE_H_
« no previous file with comments | « ios/web_view/internal/web_view_browser_state.mm ('k') | ios/web_view/internal/web_view_network_delegate.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698